CoreProgrammableInterruptController

Struct CoreProgrammableInterruptController 

#[repr(C, packed(1))]
pub struct CoreProgrammableInterruptController { pub type: u8, pub length: u8, pub version: u8, pub acpi_processor_id: u32, pub phsyical_processor_id: u32, pub flags: COREPICFlags, }
Core Programmable Interrupt Controller (CORE PIC) Structure

Each processor in Loongarch system has a Core Programmable Interrupt Controller record in the MADT, and a processor device object in the DSDT.

Fields

type: u8

17 - Core Programmable Interrupt Controller Structure

length: u8

Length of the Core Programmable Interrupt Controller Structure in bytes.

JJ’s Note: There doesn’t seem to be any variable-sized fields in this struct. The size is 15 bytes…

version: u8
  • 0x00 - Invalid
  • 0x01 - CORE PIC v1

Other values are reserved.

acpi_processor_id: u32

The OS associates this CORE PIC Structure with a processor device object in the namespace when the _UID child object of the processor device evaluates to a numeric value that matches the numeric value in this field.

phsyical_processor_id: u32

The processor core physical id.

0xFFFFFFFF is invalid value.

If invalid, this processor is unusable, and OSPM shall ignore Core Interrupt Controller Structure.

flags: COREPICFlags

CORE PIC flags.