PlatformInterruptSourceFlags

Struct PlatformInterruptSourceFlags 

pub struct PlatformInterruptSourceFlags(/* private fields */);

Implementations

Source

impl PlatformInterruptSourceFlags

pub const fn cpei_processor_override(&self) -> bool

When set, indicates that retrieval of error information is allowed from any processor and OSPM is to use the information provided by the processor ID, EID fields of the Platform Interrupt Source Structure as a target processor hint.