pub struct LocalAPICFlags(/* private fields */);Expand description
Local (S)APIC Flags
Implementations
Sourceimpl LocalAPICFlags
impl LocalAPICFlags
Sourcepub const fn enabled(&self) -> bool
pub const fn enabled(&self) -> bool
If this bit is set the processor is ready for use. If this bit is clear and the Online Capable bit is set,
system hardware supports enabling this processor during OS runtime.
If this bit is clear and the Online Capable bit is also clear, this processor is unusable,
and OSPM shall ignore the contents of the Processor Local APIC Structure.
Sourcepub const fn online_capable(&self) -> bool
pub const fn online_capable(&self) -> bool
The information conveyed by this bit depends on the value of the Enabled bit. If the Enabled bit is set, this bit is reserved and must be zero. Otherwise, if this this bit is set, system hardware supports enabling this processor during OS runtime.