pub struct GenericCommunicationsChannelStatusField(/* private fields */);Expand description
Generic Communications Channel Status Field
Implementations
Sourceimpl GenericCommunicationsChannelStatusField
impl GenericCommunicationsChannelStatusField
Sourcepub const fn command_complete(&self) -> bool
pub const fn command_complete(&self) -> bool
If set, the platform has completed processing the last command.
Sourcepub const fn platform_interrupt(&self) -> bool
pub const fn platform_interrupt(&self) -> bool
If set, the platform has issued a Platform Interrupt to this subspace.
OSPM must check the Command Complete and Platform Notification fields to determine the cause of the Interrupt.
Sourcepub const fn platform_notification(&self) -> bool
pub const fn platform_notification(&self) -> bool
If set, indicates the platform is issuing an asynchronous notification to OSPM.