RASCapabilities

Struct RASCapabilities 

pub struct RASCapabilities(/* private fields */);
Platform RAS Capabilities Bitmap

Implementations

Source

impl RASCapabilities

pub const fn hardware_based_patrol_scrub_support(&self) -> bool

Indicates that the platform supports hardware based patrol scrub of DRAM memory

pub const fn hardware_based_patrol_scrub_support_and_exposed_to_software( &self, ) -> bool

Indicates that the platform supports hardware based patrol scrub of DRAM memory and platform exposes this capability to software using this RASF mechanism