pub struct MemoryAffinity {
pub type: u8,
pub length: u8,
pub proximity_domain: u32,
pub base_address_low: u32,
pub base_address_high: u32,
pub length_low: u32,
pub length_high: u32,
pub flags: MemoryAffinityStructureFlags,
/* private fields */
}Expand description
Memory Affinity Structure
The Memory Affinity structure provides the following topology information statically to the operating system:
- The association between a memory range and the proximity domain to which it belongs
- Information about whether the memory range can be hot-plugged.
Fields
type: u81 - Memory Affinity Structure
length: u840
proximity_domain: u32Integer that represents the proximity domain to which the memory range belongs.
base_address_low: u32Low 32 Bits of the Base Address of the memory range.
base_address_high: u32High 32 Bits of the Base Address of the memory range.
length_low: u32Low 32 Bits of the length of the memory range.
length_high: u32High 32 Bits of the length of the memory range.
flags: MemoryAffinityStructureFlagsFlags - Memory Affinity Structure.
Indicates whether the region of memory is enabled and can be hot plugged.