MemoryAffinityStructureFlags

Struct MemoryAffinityStructureFlags 

pub struct MemoryAffinityStructureFlags(/* private fields */);
Flags - Memory Affinity Structure

Implementations

Source

impl MemoryAffinityStructureFlags

pub const fn enabled(&self) -> bool

If clear, the OSPM ignores the contents of the Memory Affinity Structure. This allows system firmware to populate the SRAT with a static number of structures but only enable then as necessary.

pub const fn hot_pluggable(&self) -> bool

The information conveyed by this bit depends on the value of the Enabled bit.

If the Enabled bit is set and the Hot Pluggable bit is also set. The system hardware supports hot-add and hot-remove of this memory region If the Enabled bit is set and the Hot Pluggable bit is clear, the system hardware does not support hot-add or hot-remove of this memory region.

If the Enabled bit is clear, the OSPM will ignore the contents of the Memory Affinity Structure

pub const fn non_volatile(&self) -> bool

If set, the memory region represents Non-Volatile memory