#[repr(C, packed(1))]pub struct ProcessorLocalAPICAffinity {
pub type: u8,
pub length: u8,
pub proximity_domain_7_0: u8,
pub apic_id: u8,
pub flags: ProcessorLocalAPICAffinityFlags,
pub local_sapic_eid: u8,
pub proximity_domain_31_8: [u8; 3],
pub clock_domain: u32,
}Expand description
Processor Local APIC/SAPIC Affinity Structure
The Processor Local APIC/SAPIC Affinity structure provides the association between the APIC ID or SAPIC ID/EID of a processor and the proximity domain to which the processor belongs.
Fields
type: u80 - Processor Local APIC/SAPIC Affinity Structure
length: u816
proximity_domain_7_0: u8Bit [[7:0]] of the proximity domain to which the processor belongs.
apic_id: u8The processor local APIC ID.
flags: ProcessorLocalAPICAffinityFlagsFlags for the Processor Local APIC/SAPIC Affinity Structure.
local_sapic_eid: u8The processor local SAPIC EID.
proximity_domain_31_8: [u8; 3]Bit [[31:8]] of the proximity domain to which the processor belongs.
clock_domain: u32The clock domain to which the processor belongs. See _CDM (Clock Domain).