SDTHeader

Struct SDTHeader 

#[repr(C, packed(1))]
pub struct SDTHeader { pub signature: [u8; 4], pub length: u32, pub revision: u8, pub checksum: u8, pub oemid: [u8; 6], pub oem_table_id: [u8; 8], pub oem_revision: u32, pub creator_id: u32, pub creator_revision: u32, }
System Description Table Header structure.

All system description tables begin with the structure shown in the SDTHeader Fields. The signature field in this table determines the content of the system description table.

Fields

signature: [u8; 4]

The ASCII string representation of the table identifier. Note that if OSPM finds a signature in a table that is not listed in this table, then OSPM ignores the entire table (it is not loaded into ACPI namespace); OSPM ignores the table even though the values in the Length and Checksum fields are correct.

length: u32

The length of the table, in bytes, including the header, starting from offset 0. This field is used to record the size of the entire table.

revision: u8

The revision of the structure corresponding to the signature field for this table.
Larger revision numbers are backward compatible to lower revision numbers with the same signature.

checksum: u8

The entire table, including the checksum field, must add to zero to be considered valid.

oemid: [u8; 6]

An OEM-supplied string that identifies the OEM.

oem_table_id: [u8; 8]

An OEM-supplied string that the OEM uses to identify the particular data table.
This field is particularly useful when defining a definition block to distinguish definition block functions. The OEM assigns each dissimilar structure a new OEM Table ID.

oem_revision: u32

An OEM-supplied revision number. Larger numbers are assumed to be newer revisions.

creator_id: u32

Vendor ID of utility that created the table. For tables containing Definition Blocks, this is the ID for the ASL Compiler.

creator_revision: u32

Revision of utility that created the table. For tables containing Definition Blocks, this is the revision for the ASL Compiler.