ExtendedSystemDescriptionTable

Struct ExtendedSystemDescriptionTable 

#[repr(C, packed(1))]
pub struct ExtendedSystemDescriptionTable { pub header: SDTHeader, pub entry: [u64; 0], }
Extended System Description Table structure.

Fields

header: SDTHeader
  • Signature - “XSDT”
  • Revision - 1
  • OEM Table ID - For the XSDT, the table ID is the manufacture model ID. This field must match the OEM Table ID in the FADT structure.
entry: [u64; 0]

An array of 64-bit physical addresses that point to other System Description Tables. OSPM assumes at least the System Description Table is addressable, and then can further address the table based upon its Length field.

Implementations