pub struct CorrectedPlatformErrorPolling {
pub header: SDTHeader,
pub cpep_processor_structures: [CorrectedPlatformErrorPollingProcessor; 0],
/* private fields */
}Expand description
Corrected Platform Error Polling Table (CPEP)
Platforms may contain the ability to detect and correct certain operational errors while maintaining platform function. These errors may be logged by the platform for the purpose of retrieval. Depending on the underlying hardware support, the means for retrieving corrected platform error information varies. If the platform hardware supports interrupt-based signaling of corrected platform errors, the MADT Platform Interrupt Source Structure describes the Corrected Platform Error Interrupt (CPEI). Alternatively, OSPM may poll processors for corrected platform error information. Error log information retrieved from a processor may contain information for all processors within an error reporting group. As such, it may not be necessary for OSPM to poll all processors in the system to retrieve complete error information. This optional table provides information that allows OSPM to poll only the processors necessary for a complete report of the platform’s corrected platform error information.
Fields
header: SDTHeader- Signature - “CPEP”
cpep_processor_structures: [CorrectedPlatformErrorPollingProcessor; 0]A list of Corrected Platform Error Polling Processor structures for the platform.
Implementations
Sourceimpl CorrectedPlatformErrorPolling
impl CorrectedPlatformErrorPolling
pub const fn cpep_processor_structures( &self, ) -> &[CorrectedPlatformErrorPollingProcessor]