pub struct GICCPUInterfaceFlags(/* private fields */);Expand description
GIC CPU Interface Flags
Implementations
Sourceimpl GICCPUInterfaceFlags
impl GICCPUInterfaceFlags
Sourcepub const fn enabled(&self) -> bool
pub const fn enabled(&self) -> bool
If this bit is set, the processor is ready for use. If this bit is clear and the Online Capable bit is set, the system supports enabling this processor during OS runtime.
If this bit is clear and the Online Capable bit is also clear, this processor is unusable, and the operating system support will not attempt to use it.
Sourcepub const fn performance_interrupt_mode(&self) -> bool
pub const fn performance_interrupt_mode(&self) -> bool
- 0 - Level-triggered
- 1 - Edge-triggered
Sourcepub const fn vgic_maintenance_interrupt_mode_flags(&self) -> bool
pub const fn vgic_maintenance_interrupt_mode_flags(&self) -> bool
- 0 - Level-triggered
- 1 - Edge-triggered
Sourcepub const fn online_capable(&self) -> bool
pub const fn online_capable(&self) -> bool
The information conveyed by this bit depends on the value of the Enabled bit.
If the Enabled bit is set, this bit is reserved and must be zero. Otherwise, if this bit is set, the system supports enabling this processor later during OS runtime.