#[repr(C, packed(1))]pub struct MaximumSystemCharacteristicsTable {
pub header: SDTHeader,
pub offset_prox_dom_info: u32,
pub max_number_of_proximity_domains: u32,
pub max_number_of_clock_domains: u32,
pub max_physical_address: u64,
}Expand description
Maximum System Characteristics Table (MSCT)
This section describes the format of the Maximum System Characteristic Table (MSCT), which provides OSPM with information characteristics of a system’s maximum topology capabilities. If the system maximum topology is not known up front at boot time, then this table is not present. OSPM will use information provided by the MSCT only when the System Resource Affinity Table (SRAT) exists. The MSCT must contain all proximity and clock domains defined in the SRAT.
Fields
header: SDTHeader- Signature - “MSCT”
offset_prox_dom_info: u32Offset in bytes to the Proximity Domain Information Structure table entry.
max_number_of_proximity_domains: u32Indicates the maximum number of Proximity Domains ever possible in the system.
The number reported in this field is (maximum domains - 1). For example if there are 0x10000 possible domains in the system, this field would report 0xFFFF.
max_number_of_clock_domains: u32Indicates the maximum number of Clock Domains ever possible in the system.
The number reported in this field is (maximum domains - 1).
max_physical_address: u64Indicates the maximum Physical Address ever possible in the system.
Note: this is the top of the reachable physical address.
Implementations
Sourceimpl MaximumSystemCharacteristicsTable
impl MaximumSystemCharacteristicsTable
Sourcepub const fn proximity_domain_information(
&self,
) -> &[MaximumProximityDomainInformation]
pub const fn proximity_domain_information( &self, ) -> &[MaximumProximityDomainInformation]
JJ’s Note: The specs say that this field is located somewhere depending on the offset field in the structure (not aligned with the structure at all), which is why I provided this.