pub struct PlatformCommunicationsChannel {
pub header: SDTHeader,
pub flags: PCCGlobalFlags,
pub pcc_subspace_structure: [u8; 0],
/* private fields */
}Expand description
Platform Communications Channel (PCC)
The platform communication channel (PCC) is a generic mechanism for OSPM to communicate with an entity in the platform (e.g. a platform controller, or a Baseboard Management Controller (BMC)). Neither the entity that OSPM communicates with, nor any aspects of the information passed back and forth is defined in this section. That information is defined by the actual interface that that employs PCC register address space as the communication channel.
PCC defines a new address space type (PCC Space, 0xA), which is implemented as one or more independent communications channels, or subspaces.
Fields
header: SDTHeader- Signature - “PCCT”
flags: PCCGlobalFlagsPlatform Communications Channel Global flags.
pcc_subspace_structure: [u8; 0]A list of Platform Communications Channel Subspace structures for this platform. At most 256 subspaces are supported.