GenericCommunicationsChannelCommandField

Struct GenericCommunicationsChannelCommandField 

pub struct GenericCommunicationsChannelCommandField(/* private fields */);
Generic Communications Channel Command Field

For channels of type 0 to 2, this 16-bit field is used to select one of the defined commands for the platform to perform. OSPM is responsible for populating this field before each command invocation.

Implementations

Source

impl GenericCommunicationsChannelCommandField

pub const fn command(&self) -> u8

Command code to execute.

Command codes are application specific and defined by the consumer of this interface.

pub const fn notify_on_completion(&self) -> bool

If set, the platform should generate a Doorbell interrupt at the completion of this command. The interrupt is an SCI for a Type 0 subspace structure, or as described by the Doorbell Interrupt field for Type 1 and Type 2 subspace structures. If the Doorbell bit is not set in the PCC global flags, this bit must be cleared.