GenericCommunicationsChannelStatusField

Struct GenericCommunicationsChannelStatusField 

pub struct GenericCommunicationsChannelStatusField(/* private fields */);
Generic Communications Channel Status Field

Implementations

Source

impl GenericCommunicationsChannelStatusField

pub const fn command_complete(&self) -> bool

If set, the platform has completed processing the last command.

pub const fn platform_interrupt(&self) -> bool

If set, the platform has issued a Platform Interrupt to this subspace.

OSPM must check the Command Complete and Platform Notification fields to determine the cause of the Interrupt.

pub const fn error(&self) -> bool

If set, an error occurred executing the last command.

pub const fn platform_notification(&self) -> bool

If set, indicates the platform is issuing an asynchronous notification to OSPM.