#[repr(C, packed(1))]pub struct PersistentSystemDescriptionTable {
pub header: SDTHeader,
pub def_block: [u8; 0],
}Expand description
Persistent System Description Table
The table signature, “PSDT” refers to the Persistent System Description Table (PSDT) defined in the ACPI 1.0 specification. The PSDT was judged to provide no specific benefit and as such has been deleted from follow-on versions of the ACPI specification. OSPM will evaluate a table with the “PSDT” signature in like manner to the evaluation of an SSDT as described in Section 5.2.11.2
Fields
header: SDTHeader- Signature - “PSDT”
def_block: [u8; 0]The bytes of AML code.
Implementations