pub struct RASCapabilities(/* private fields */);Expand description
Platform RAS Capabilities Bitmap
Implementations
Sourceimpl RASCapabilities
impl RASCapabilities
Sourcepub const fn hardware_based_patrol_scrub_support(&self) -> bool
pub const fn hardware_based_patrol_scrub_support(&self) -> bool
Indicates that the platform supports hardware based patrol scrub of DRAM memory
Sourcepub const fn hardware_based_patrol_scrub_support_and_exposed_to_software(
&self,
) -> bool
pub const fn hardware_based_patrol_scrub_support_and_exposed_to_software( &self, ) -> bool
Indicates that the platform supports hardware based patrol scrub of DRAM memory and platform exposes this capability to software using this RASF mechanism