#[repr(C, packed(1))]pub struct RootSystemDescriptionTable {
pub header: SDTHeader,
pub entry: [u32; 0],
}Expand description
Root System Description Table structure.
Fields
header: SDTHeader- Signature - “RSDT”
- Revision - 1
- OEM Table ID - For the RSDT, the table ID is the manufacture model ID. This field must match the OEM Table ID in the FADT structure.
entry: [u32; 0]An array of 32-bit physical addresses that point to other System Description Tables.
OSPM assumes at least the System Description Table is addressable, and then can further address the table based upon its Length field.
Implementations